.. _Packages:

Packages
========

`Steamship Packages <https://www.steamship.com/packages>`_ are cloud-hosted software libraries you can use in any programming environment.

Think of them as regular software libraries with an upgrade:

- **Packages bundle a full-lifecycle AI stack.**
  Everything necessary to go from demo to production in minutes: code, models, data, and infrastructure.

- **Packages auto-manage their own infrastructure.**
  If a package depends on an embedding index or a fine-tuned model, you don't have to care.

- **Packages are stateful.**
  You can create as many instances as you want: one per user, one per chat room, one per document folder. They remember their context.

That gives you the ability to use the full breadth of modern AI with a single ``import`` statement.

.. grid::  1 1 2 3

   .. grid-item-card:: **Using Packages**
      :link: using.html

      Import and use full-lifecycle language-AI packages in your Python, Javascript, and HTTP projects.

   .. grid-item-card:: **Developing Packages**
      :link: developing/index.html

      Build and deploy your own packages with our low-code framework. Works with your favorite AI services.

   .. grid-item-card:: **Package Cookbook**
      :link: cookbook/index.html

      Code snippets for converting content, tagging entities, searching content, and more.

Packages Table of Contents
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 2

   Using Packages <using>
   Developing Packages <developing/index>
   Package Project Structure <developing/project-structure>
   Package Cookbook <cookbook/index>
